@@ -2,6 +2,7 @@ import paperqa
 import requests
 import os
 import pickle
+from paperqa.utils import strings_similarity
 
 
 def test_maybe_is_text():
@@ -38,7 +39,7 @@ def test_evidence():
         f.write(r.text)
     docs = paperqa.Docs()
     docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
-    evidence = docs.get_evidence(
+    evidence, _ = docs.get_evidence(
         "For which state was he a governor", k=1, max_sources=1
     )
     assert "Missouri" in evidence
@@ -69,9 +70,13 @@ def test_docs_pickle():
     docs_pickle = pickle.dumps(docs)
     docs2 = pickle.loads(docs_pickle)
     assert len(docs.docs) == len(docs2.docs)
-    assert docs.get_evidence(
-        "What is the date?", k=1, max_sources=1
-    ) == docs2.get_evidence("What is the date?", k=1, max_sources=1)
+    assert (
+        strings_similarity(
+            docs.get_evidence("What is the date?", k=1, max_sources=1)[0],
+            docs2.get_evidence("What is the date?", k=1, max_sources=1)[0],
+        )
+        > 0.75
+    )
     os.remove(doc_path)
 
 
@@ -119,3 +124,12 @@ def test_repeat_keys():
 
     os.remove(doc_path)
     os.remove(doc_path2)
+
+
+def test_pdf_reader():
+    tests_dir = os.path.dirname(os.path.abspath(__file__))
+    doc_path = os.path.join(tests_dir, "paper.pdf")
+    docs = paperqa.Docs()
+    docs.add(doc_path, "Wellawatte et al, XAI Review, 2023")
+    answer = docs.query("What is LIME?")
+    assert "Local Interpretable Model-Agnostic Explanations" in answer.answer
